var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import handleSearchRequest from "./handlers/search";
import handleAutocompleteRequest from "./handlers/autocomplete";
import { EngineTransporter } from "./handlers/transporter";
export * from "./types";
function isTransporter(config) {
    return config.performRequest !== undefined;
}
class EngineConnector {
    constructor(config) {
        this.config = config;
        if (isTransporter(config)) {
            this.transporter = config;
        }
        else {
            if (!config.host) {
                throw new Error("Engine Host must be provided.");
            }
            if (!config.engineName) {
                throw new Error("Engine Name must be provided.");
            }
            if (!config.apiKey) {
                throw new Error("API Key must be provided.");
            }
            const { host, engineName, apiKey } = config;
            this.transporter = new EngineTransporter(host, engineName, apiKey);
        }
    }
    // eslint-disable-next-line @typescript-eslint/no-empty-function
    onResultClick() { }
    // eslint-disable-next-line @typescript-eslint/no-empty-function
    onAutocompleteResultClick() { }
    onSearch(state, queryConfig) {
        return __awaiter(this, void 0, void 0, function* () {
            return handleSearchRequest({
                state,
                queryConfig,
                transporter: this.transporter
            });
        });
    }
    onAutocomplete(state, queryConfig) {
        return __awaiter(this, void 0, void 0, function* () {
            return handleAutocompleteRequest({
                state,
                queryConfig,
                transporter: this.transporter
            });
        });
    }
}
export default EngineConnector;
